pub struct GithubPullRequestClient { /* private fields */ }Implementations
Sourceimpl GithubPullRequestClient
impl GithubPullRequestClient
pub fn new( http_client: Arc<HttpClient>, ) -> ResultDynError<GithubPullRequestClient>
Sourceimpl GithubPullRequestClient
impl GithubPullRequestClient
pub async fn create<'a>( &self, input: CreatePullRequestInput<'a>, ) -> ResultDynError<Value>
pub async fn merge<'a>( &self, input: MergePullRequestInput<'a>, ) -> ResultDynError<Value>
Sourcepub async fn get_by_head<'a>(
&self,
input: GetPullRequestByHeadInput<'a>,
) -> ResultDynError<Option<Value>>
pub async fn get_by_head<'a>( &self, input: GetPullRequestByHeadInput<'a>, ) -> ResultDynError<Option<Value>>
Get pull request by head in format {branch_owner}:{branch_name}'
So for example if my user is sendyhalim and I’m creating a PR
with branch name x then head will be sendyhalim:x.